<?php

/**
 * @file
 * Photoswipe theme preprocess functions.
 */

use Drupal\image\Entity\ImageStyle;

/**
 * Prepares variables for a UIkit lightbox image field formatter.
 *
 * @param array $variables
 *   An associative array containing:
 *   - item: An ImageItem object.
 *   - display_settings: optional image styles.
 *
 * @ingroup themeable
 */
function template_preprocess_uikit_lightbox(array &$variables) {
  $item = $variables['item'];
  $settings = $variables['display_settings'];
  $uri = $item->entity->getFileUri();
  $alt = !empty($item->alt) ? $item->alt : '';
  $title = !empty($item->title) ? $item->title : '';

  $caption = '';
  if (!empty($alt)) {
    $caption = $alt;
  }
  elseif (!empty($title)) {
    $caption = $title;
  }

  $image = [
    '#theme' => 'image_style',
    '#uri' => $uri,
    '#alt' => $alt,
    '#title' => $title,
    '#attributes' => $item->_attributes,
    '#style_name' => $settings['content']['style'],
  ];

  $dimensions = [];
  if (isset($item->width) && isset($item->height)) {
    $image['#width'] = $dimensions['width'] = $item->width;
    $image['#height'] = $dimensions['height'] = $item->height;
  }

  // Create the path to the image that will show in Lightbox.
  if ($style_name = $settings['content']['lightbox_style']) {
    // Load the image style.
    $style = ImageStyle::load($style_name);
    // Fetch the Image style path from the Image URI.
    $path = $style->buildUrl($uri);
    // Set the dimensions.
    $style->transformDimensions($dimensions, $uri);
  }
  else {
    $path = file_create_url($uri);
  }

  // Render as a standard image if an image style is not given.
  if (empty($image['#style_name'])) {
    $image['#theme'] = 'image';
  }

  $variables['image'] = $image;
  $variables['path'] = $path;

  if (!empty($caption)) {
    $variables['attributes'] = [
      'data-alt' => $caption,
      'data-caption' => $caption,
    ];
  }
}

/**
 * Prepares variables for a UIkit Slideshow image field formatter.
 *
 * @param array $variables
 *   An associative array containing:
 *   - item: An ImageItem object.
 *   - display_settings: optional image styles.
 *
 * @ingroup themeable
 */
function template_preprocess_uikit_slideshow(array &$variables) {
  $item = $variables['item'];
  $settings = $variables['display_settings'];
  $uri = $item->entity->getFileUri();
  $alt = !empty($item->alt) ? $item->alt : '';
  $title = !empty($item->title) ? $item->title : '';

  $caption = '';
  if (!empty($alt)) {
    $caption = $alt;
  }
  elseif (!empty($title)) {
    $caption = $title;
  }

  $image = [
    '#theme' => 'image_style',
    '#uri' => $uri,
    '#alt' => $alt,
    '#title' => $title,
    '#attributes' => $item->_attributes,
    '#style_name' => $settings['content']['style'],
  ];

  $dimensions = [];
  if (isset($item->width) && isset($item->height)) {
    $image['#width'] = $dimensions['width'] = $item->width;
    $image['#height'] = $dimensions['height'] = $item->height;
  }

  // Render as a standard image if an image style is not given.
  if (empty($image['#style_name'])) {
    $image['#theme'] = 'image';
  }

  // Create the path to the image that will show in Lightbox if lightbox enabled
  if($settings['lightbox']['enabled']) {
    if ($style_name = $settings['lightbox']['style']) {
      // Load the image style.
      $style = ImageStyle::load($style_name);
      // Fetch the Image style path from the Image URI.
      $path = $style->buildUrl($uri);
      // Set the dimensions.
      $style->transformDimensions($dimensions, $uri);
    }
    else {
      $path = file_create_url($uri);
    }
    if (!empty($caption)) {
      $variables['attributes'] = [
        'data-alt' => $caption,
        'data-caption' => $caption,
      ];
    }
  }

  $variables['path'] = $path;
  $variables['uri'] = $uri;
  $variables['image'] = $image;
}

/**
 * Prepares variables for a UIkit Slider image field formatter.
 *
 * @param array $variables
 *   An associative array containing:
 *   - item: An ImageItem object.
 *   - display_settings: optional image styles.
 *
 * @ingroup themeable
 */
function template_preprocess_uikit_slider(array &$variables) {
  $item = $variables['item'];
  $settings = $variables['display_settings'];
  $uri = $item->entity->getFileUri();
  $alt = !empty($item->alt) ? $item->alt : '';
  $title = !empty($item->title) ? $item->title : '';

  $caption = '';
  if (!empty($alt)) {
    $caption = $alt;
  }
  elseif (!empty($title)) {
    $caption = $title;
  }

  $image = [
    '#theme' => 'image_style',
    '#uri' => $uri,
    '#alt' => $alt,
    '#title' => $title,
    '#attributes' => $item->_attributes,
    '#style_name' => $settings['content']['style'],
  ];

  $dimensions = [];
  if (isset($item->width) && isset($item->height)) {
    $image['#width'] = $dimensions['width'] = $item->width;
    $image['#height'] = $dimensions['height'] = $item->height;
  }

  // Render as a standard image if an image style is not given.
  if (empty($image['#style_name'])) {
    $image['#theme'] = 'image';
  }

  // Create the path to the image that will show in Lightbox if lightbox enabled
  if($settings['lightbox']['enabled']) {
    if ($style_name = $settings['lightbox']['style']) {
      // Load the image style.
      $style = ImageStyle::load($style_name);
      // Fetch the Image style path from the Image URI.
      $path = $style->buildUrl($uri);
      // Set the dimensions.
      $style->transformDimensions($dimensions, $uri);
    }
    else {
      $path = file_create_url($uri);
    }
    if (!empty($caption)) {
      $variables['attributes'] = [
        'data-alt' => $caption,
        'data-caption' => $caption,
      ];
    }
  }

  $variables['path'] = $path;
  $variables['uri'] = $uri;
  $variables['image'] = $image;
}
